==> foundation-ui-components-1.26.1.tgz: package/src/common/card/specs/NsHeroCardLevel2.spec.tsx <==
import React from 'react';
import { render, screen } from '@testing-library/react';
import { NsHeroCardLevel2 } from '../';

describe('NsHeroCardLevel2 component', () => {
    const props = {
        cardTitle: 'Current shop deals',
        cardDescription: 'Lumispa, sunscreen and more',
        brandName: 'Beauty focus™',
        backgroundImageUrl: 'https://media.nuskin.com/m/5f1c423bb57589f0/webimage-autumn-sale-carousel.png',
        backgroundImageAlt: 'lash brow serum carousel',
        button: {
            showButton: true,
            buttonText: 'Discover more',
            buttonVariant: 'text' as 'text',
            buttonColor: 'secondary' as 'secondary',
            url: '#',
            endIcon: 'home' as 'home',
        },
    };

    it('1. renders with correct content and styles', () => {
        render(<NsHeroCardLevel2 {...props} />);

        const cardContainer = screen.getByTestId('hero-card-level-2');
        expect(cardContainer).toBeInTheDocument();

        const brandText = screen.getByText('Beauty focus™');
        expect(brandText).toBeInTheDocument();

        const textContent = screen.getByText('Current shop deals');
        expect(textContent).toBeInTheDocument();

        const bodyContent = screen.getByText('Lumispa, sunscreen and more');
        expect(bodyContent).toBeInTheDocument();

        const button = screen.queryByText('Discover more');
        expect(button).toBeInTheDocument();
    });

    it('2. does not render button when button prop is false', () => {
        let updatedProps = { ...props };
        updatedProps.button.showButton = false;
        render(<NsHeroCardLevel2 {...updatedProps} />);

        const button = screen.queryByText('Discover more');
        expect(button).not.toBeInTheDocument();
    });
});

==> foundation-ui-components-1.30.1.tgz: package/src/common/card/specs/NsHeroCardLevel2.spec.tsx <==
import React from 'react';
import { render, screen } from '@testing-library/react';
import { NsHeroCardLevel2 } from '../';
import { ImageData1 } from '../fixtures/ImageData1';

describe('NsHeroCardLevel2 component', () => {
    const props = {
        cardTitle: 'Current shop deals',
        cardDescription: 'Lumispa, sunscreen and more',
        brandName: 'Beauty focus™',
        backgroundImageDetail: ImageData1,
        button: {
            showButton: true,
            buttonText: 'Discover more',
            buttonVariant: 'text' as 'text',
            buttonColor: 'secondary' as 'secondary',
            url: '#',
            endIcon: 'home' as 'home',
        },
    };

    it('1. renders with correct content and styles', () => {
        render(<NsHeroCardLevel2 {...props} />);

        const cardContainer = screen.getByTestId('hero-card-level-2');
        expect(cardContainer).toBeInTheDocument();

        const brandText = screen.getByText('Beauty focus™');
        expect(brandText).toBeInTheDocument();

        const textContent = screen.getByText('Current shop deals');
        expect(textContent).toBeInTheDocument();

        const bodyContent = screen.getByText('Lumispa, sunscreen and more');
        expect(bodyContent).toBeInTheDocument();

        const button = screen.queryByText('Discover more');
        expect(button).toBeInTheDocument();
    });

    it('2. does not render button when button prop is false', () => {
        let updatedProps = { ...props };
        updatedProps.button.showButton = false;
        render(<NsHeroCardLevel2 {...updatedProps} />);

        const button = screen.queryByText('Discover more');
        expect(button).not.toBeInTheDocument();
    });
});
